srboo.SrbException

|  | ## Cheshire3 Object Model: Class SrbException

Module srboo :: Class SrbException

## Class SrbException
source code

Object Tree:

    exceptions.Exception --+
                           |
                          SrbException

Instance Methods

__init__(self, type, info="")
__repr__(self)
__str__(self)
Inherited from `exceptions.Exception`: `__getitem__`

Method Details

### __init__(self, type, info="") (Constructor) | source code
Overrides: exceptions.Exception.__init__

### __repr__(self) (Representation operator) | source code

### __str__(self) (Informal representation operator) | source code
Overrides: exceptions.Exception.__str__